// PPgDirectories.cpp : implementation file
//

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif // HAVE_CONFIG_H

// Test if we have _GNU_SOURCE before the next step will mess up 
// setting __USE_GNU 
// (only needed for gcc-2.95 compatibility, gcc 3.2 always defines it)
#include "wx/setup.h"

// Mario Sergio Fujikawa Ferreira <lioux@FreeBSD.org>
// to detect if this is a *BSD system
#if defined(HAVE_SYS_PARAM_H)
#include <sys/param.h>
#endif

//#include "stdafx.h"
#include "wintypes.h"
#include "amule.h"
#include "PPgDirectories.h"

#include "DirectoryTreeCtrl.h"
#include <wx/checkbox.h>
#include <wx/notebook.h>
#include <wx/slider.h>
#include <wx/dirdlg.h>
#include <wx/filedlg.h>
#include "muuli_wdr.h"

// *BSD compatibility
#if (defined(BSD) && (BSD >= 199103))
#define MAX_PATH MAXPATHLEN
#else
#define MAX_PATH 2048
#endif

// CPPgDirectories dialog

IMPLEMENT_DYNAMIC_CLASS(CPPgDirectories,wxPanel)

//IMPLEMENT_DYNAMIC(CPPgDirectories, CPropertyPage)
CPPgDirectories::CPPgDirectories(wxWindow* parent)
: wxPanel(parent,CPPgDirectories::IDD)
{
	wxNotebook* book=(wxNotebook*)parent;

	wxSizer* page1=PreferencesDirectoriesTab(this,TRUE);
	book->AddPage(this,_("Directories"));

	m_ShareSelector=((CDirectoryTreeCtrl*)FindWindowById(IDC_SHARESELECTOR));
}

CPPgDirectories::~CPPgDirectories()
{
}

BEGIN_EVENT_TABLE(CPPgDirectories,wxPanel)
	EVT_BUTTON(IDC_SELTEMPDIR,CPPgDirectories::OnBnClickedSeltempdir)
	EVT_BUTTON(IDC_SELINCDIR,CPPgDirectories::OnBnClickedSelincdir)
	EVT_BUTTON(IDC_BROWSEV,CPPgDirectories::BrowseVideoplayer)
END_EVENT_TABLE()

void CPPgDirectories::LoadSettings(void)
{
	((wxTextCtrl*)FindWindowById(IDC_INCFILES))->SetValue(app_prefs->prefs->incomingdir);
	((wxTextCtrl*)FindWindowById(IDC_TEMPFILES))->SetValue(app_prefs->prefs->tempdir);

	m_ShareSelector->SetSharedDirectories(&app_prefs->shareddir_list);

	((wxTextCtrl*)FindWindowById(IDC_VIDEOPLAYER))->SetValue(app_prefs->prefs->VideoPlayer);
	if(app_prefs->prefs->moviePreviewBackup) {
		((wxCheckBox*)FindWindowById(IDC_VIDEOBACKUP))->SetValue(TRUE);
	} else {
		((wxCheckBox*)FindWindowById(IDC_VIDEOBACKUP))->SetValue(FALSE);
	}
}


bool CPPgDirectories::SelectDir(char* outdir, char* titletext)
{
	wxString str=wxDirSelector(titletext,"");
	if(str.IsEmpty()) {
		return FALSE;
	}

	strcpy(outdir,str.GetData());
	return TRUE;
}

void CPPgDirectories::OnBnClickedSelincdir(wxEvent& e)
{
	char buffer[MAX_PATH];
	if (SelectDir(buffer,(char*)"Choose a folder for incoming files")) {
		((wxTextCtrl*)FindWindowById(IDC_INCFILES))->SetValue(buffer);
	}
}

void CPPgDirectories::OnBnClickedSeltempdir(wxEvent& e)
{
	char buffer[MAX_PATH];
	if (SelectDir(buffer,(char*)"Choose a folder for temp files")) {
		((wxTextCtrl*)FindWindowById(IDC_TEMPFILES))->SetValue(buffer);
	}
}

void CPPgDirectories::BrowseVideoplayer(wxEvent& e)
{
	wxString str=wxFileSelector(_("Browse for videoplayer"),"","","",_("Executable (*)|*||"));
	if(!str.IsEmpty()) {
		((wxTextCtrl*)FindWindowById(IDC_VIDEOPLAYER))->SetValue(str);
	}
}

BOOL CPPgDirectories::OnApply()
{
	wxString buffer;
	bool IncomingChanged = false; // Will be set true if Incoming directory changed
	bool TempChanged = false; // Will be set true if Temp directory changed
	
	if (((wxTextCtrl*)FindWindowById(IDC_INCFILES))->GetValue().Length()) {
		buffer=((wxTextCtrl*)FindWindowById(IDC_INCFILES))->GetValue();
		if (strcmp(app_prefs->prefs->incomingdir,buffer.GetData())!=0) {
			IncomingChanged=true;
		}
		strcpy(app_prefs->prefs->incomingdir,buffer.GetData());
	}
	
	if (((wxTextCtrl*)FindWindowById(IDC_TEMPFILES))->GetValue().Length()) {
		buffer=((wxTextCtrl*)FindWindowById(IDC_TEMPFILES))->GetValue();
		if (strcmp(app_prefs->prefs->tempdir,buffer.GetData())!=0) {
			TempChanged=true;
		}
		strcpy(app_prefs->prefs->tempdir,buffer.GetData());
	}

	buffer=((wxTextCtrl*)FindWindowById(IDC_VIDEOPLAYER))->GetValue();
	strcpy(app_prefs->prefs->VideoPlayer ,buffer.GetData());

	app_prefs->prefs->moviePreviewBackup = (((wxCheckBox*)FindWindowById(IDC_VIDEOBACKUP))->IsChecked());
	app_prefs->shareddir_list.Clear();
	m_ShareSelector->GetSharedDirectories(&app_prefs->shareddir_list);

	if (IncomingChanged || TempChanged || m_ShareSelector->HasChanged) {
		theApp.sharedfiles->Reload(true, false);
	}
	
	return TRUE;
}

void CPPgDirectories::Localize(void)
{
}
